SlidableBottomAppBar class
bottom app bar can silde to the position of the screen which spicefied in maxHeight property
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SlidableBottomAppBar
Constructors
- SlidableBottomAppBar({Key? key, required Widget pageBody, Widget? body, Widget? child, SlidableBottomAppBarShape shape = SlidableBottomAppBarShape.rounded, double maxHeight = 250, bool hasCenterButton = true, void onButtonPressed()?, Widget? buttonChild, bool allowShadow = false, Color? color = Colors.blue, Color? buttonColor = Colors.blue, Color shadowColor = Colors.black, Duration animationDuration = const Duration(seconds: 1), Curve animationCurve = Curves.easeIn})
-
const
Properties
- allowShadow → bool
-
if
trueit will add a shadow around the app bar, and iffalseno shadow will be added.final - animationCurve → Curve
-
the slide show animation curve.
final
- animationDuration → Duration
-
the slide show animation duration.
final
- body → Widget?
-
body property is used to Declare the body of the app bar which will appear after clicking the button or silding if the haseCenterButton property is set to false.
final
-
the appearance child of the center button
final
-
the color of the button if the haseCenterButton property is set to false the button will not appear.
final
- child → Widget?
-
child property is used to declare the appearance content of the app bar.
final
- color → Color?
-
the color of the bottom app bar including the background color of the body property.
final
- hasCenterButton → bool
-
detrimined if there is a button in the center of the appbar or not.
trueit will show a button in the center.falseno button in the center.final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeight → double
-
the maximum height that app bar will slide to it.
final
- onButtonPressed → void Function()?
-
onButtonPressed event this Function will run after pressing the button and starting the slide show.
final
- pageBody → Widget
-
important pageBody property is used to Declare the page contents.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color
-
the color of the shadow that appeare ander the app bar over the app bar content body.
final
- shape → SlidableBottomAppBarShape
-
the shape of the app bar.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SlidableBottomAppBar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited